package cn.wisenergy.chnmuseum.party.model;

import com.baomidou.mybatisplus.annotation.*;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.*;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * <p>
 * 视频
 * </p>
 *
 * @author Danny Lee
 * @since 2021-03-16
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@TableName("asset")
@ApiModel(value = "Asset对象", description = "视频")
public class Asset implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty("视频ID")
    @TableId(value = "id", type = IdType.ASSIGN_ID)
    private String id;

    @ApiModelProperty("视频名称")
    @TableField("name")
    @NotBlank(message = "视频名称不能为空")
    private String name;

    @ApiModelProperty("视频版权方ID")
    @TableField("asset_copyright_owner_id")
    @NotBlank(message = "视频版权方ID不能为空")
    private String assetCopyrightOwnerId;

    @ApiModelProperty("视频类别ID")
    @TableField("asset_type_id")
    @NotBlank(message = "视频类别ID不能为空")
    private String assetTypeId;

    @ApiModelProperty("视频缩略图")
    @TableField("thumbnail")
    @NotBlank(message = "视频缩略图不能为空")
    private String thumbnail;

    @ApiModelProperty("视频链接")
    @TableField("video_url")
    private String videoUrl;

    @ApiModelProperty("审核状态")
    @TableField("audit_status")
    private String auditStatus;

    @ApiModelProperty("创建日期")
    @TableField(value = "create_time", fill = FieldFill.INSERT)
    private LocalDateTime createTime;

    @ApiModelProperty("修改日期")
    @TableField(value = "update_time", fill = FieldFill.INSERT_UPDATE)
    private LocalDateTime updateTime;

}
